@@ -10,7 +10,8 @@ class StingrayToken(StingrayBase):
         super().__init__(base_url)
         self.company_id = company_id
         self.current_context = {"company": company_id}
-        self.headers = {'Authorization': 'Token {0}'.format(ci_token)}
+        self.headers = {'Authorization': 'Token {0}'.format(ci_token),
+                        'Content-Type': 'application/json'}
 
     def set_headers(self, ci_token):
         self.headers = {'Authorization': 'Token {0}'.format(ci_token)}
